@@ -26,6 +26,7 @@ from ._recon import recon_action_payload, recon_action_update_payload, recon_rul
 from ._recon import recon_notifications_payload, recon_rule_preview_payload
 from ._malquery import malquery_exact_search_payload, malquery_hunt_payload, malquery_fuzzy_payload
 from ._detects import update_detects_payload
+from ._incidents import incident_action_parameters
 from ._ioa import ioa_exclusion_payload, ioa_custom_payload
 from ._prevention_policy import prevention_policy_payload
 from ._sensor_update_policy import sensor_policy_payload
@@ -56,5 +57,5 @@ __all__ = [
     "cspm_policy_payload", "cspm_scan_payload", "device_policy_payload", "falconx_payload",
     "mssp_payload", "ioa_custom_payload", "firewall_policy_payload", "firewall_container_payload",
     "firewall_rule_group_payload", "firewall_rule_group_update_payload", "reports_payload",
-    "activity_payload", "case_payload"
+    "activity_payload", "case_payload", "incident_action_parameters"
 ]
