@@ -150,7 +150,7 @@ class HostGroup(ServiceClass):
                 {
                     "action_parameters": [
                         {
-                            "name": "string",
+                            "name": "filter",
                             "value": "string"
                         }
                     ],
@@ -158,6 +158,8 @@ class HostGroup(ServiceClass):
                         "string"
                     ]
                 }
+        filter -- Filter to use to specify hosts to apply this action to. FQL formatted string.
+                  Overridden if action_parameters is specified.
         ids -- List of host group IDs to perform an action against. String or list of strings.
 
         This method only supports keywords for providing arguments.
@@ -173,6 +175,12 @@ class HostGroup(ServiceClass):
             body = generic_payload_list(submitted_keywords=kwargs,
                                         payload_value="ids"
                                         )
+            if kwargs.get("filter", None):
+                body["action_parameters"] = [{
+                    "name": "filter",
+                    "value": kwargs.get("filter", None)
+                }]
+            # Passing an action_parameters list will override the filter keyword
             if kwargs.get("action_parameters", None):
                 body["action_parameters"] = kwargs.get("action_parameters", None)
 
